Tempo.Iso8601.Tokenizer (Tempo v0.20.0)

Copy Markdown View Source

Tokenizes an ISO 8601 (parts 1 and 2) or IXDTF string into a list of tagged tokens that the internal parser then converts into a Tempo.t/0 struct.

tokenize/1 returns a 2-tuple {tokens, extended_info} where extended_info is either nil or a map of parsed IXDTF suffix information. See Tempo.Iso8601.Tokenizer.Extended for the shape of the extended map.

Summary

Functions

datetime_or_date_or_time__0(rest, acc, stack, context, line, offset)

datetime_or_date_or_time__1(rest, acc, stack, context, line, offset)

datetime_or_date_or_time__2(rest, acc, stack, context, line, offset)

datetime_or_date_or_time__3(rest, acc, list, context, line, offset)

datetime_or_date_or_time__4(_, _, stack, _, _, _)

datetime_or_date_or_time__5(rest, acc, stack, context, line, offset)

datetime_or_date_or_time__6(rest, acc, list, context, line, offset)

datetime_or_date_or_time__7(_, _, stack, _, _, _)

datetime_or_date_or_time__8(rest, acc, stack, context, line, offset)

datetime_or_date_or_time__9(rest, acc, list, context, line, offset)

iso8601(binary, opts \\ [])

@spec iso8601(binary(), keyword()) ::
  {:ok, [term()], rest, context, line, byte_offset}
  | {:error, reason, rest, context, line, byte_offset}
when line: {pos_integer(), byte_offset},
     byte_offset: non_neg_integer(),
     rest: binary(),
     reason: String.t(),
     context: map()

Parses the given binary as iso8601.

Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the iso8601 (start position) as {line, offset_to_start_of_line}.

To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.

Options

  • :byte_offset - the byte offset for the whole binary, defaults to 0
  • :line - the line and the byte offset into that line, defaults to {1, byte_offset}
  • :context - the initial context value. It will be converted to a map

set__0(rest, acc, stack, context, line, offset)

set__1(rest, acc, stack, context, line, offset)

set__2(rest, acc, stack, context, line, offset)

set__3(rest, acc, list, context, line, offset)

set__4(_, _, stack, _, _, _)

set__5(rest, acc, stack, context, line, offset)

set__6(rest, acc, list, context, line, offset)

set__7(_, _, stack, _, _, _)

set__8(rest, acc, stack, context, line, offset)

set__9(rest, acc, list, context, line, offset)

set__10(_, _, stack, _, _, _)

set__11(rest, acc, stack, context, line, offset)

set__12(rest, acc, list, context, line, offset)

tokenize(string)

Tokenize an ISO 8601 or IXDTF string.

Arguments

  • string is any ISO 8601 formatted string, optionally with an IXDTF suffix (such as [Europe/Paris][u-ca=hebrew]).

Returns

  • {:ok, {tokens, extended_info}} where tokens is the list of ISO 8601 tokens produced by the parser and extended_info is either nil (when no IXDTF suffix was present) or a map with keys :calendar, :zone_id, :zone_offset and :tags.

  • {:error, reason} when the string cannot be parsed or a critical IXDTF suffix is unrecognised.