Tokenizes an ISO 8601 (parts 1 and 2) or IXDTF string into a
list of tagged tokens that the internal parser then converts
into a Tempo.t/0 struct.
tokenize/1 returns a 2-tuple {tokens, extended_info} where
extended_info is either nil or a map of parsed
IXDTF
suffix information. See Tempo.Iso8601.Tokenizer.Extended for
the shape of the extended map.
Summary
Functions
@spec iso8601(binary(), keyword()) :: {:ok, [term()], rest, context, line, byte_offset} | {:error, reason, rest, context, line, byte_offset} when line: {pos_integer(), byte_offset}, byte_offset: non_neg_integer(), rest: binary(), reason: String.t(), context: map()
Parses the given binary as iso8601.
Returns {:ok, [token], rest, context, position, byte_offset} or
{:error, reason, rest, context, line, byte_offset} where position
describes the location of the iso8601 (start position) as {line, offset_to_start_of_line}.
To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.
Options
:byte_offset- the byte offset for the whole binary, defaults to 0:line- the line and the byte offset into that line, defaults to{1, byte_offset}:context- the initial context value. It will be converted to a map
Tokenize an ISO 8601 or IXDTF string.
Arguments
stringis any ISO 8601 formatted string, optionally with an IXDTF suffix (such as[Europe/Paris][u-ca=hebrew]).
Returns
{:ok, {tokens, extended_info}}wheretokensis the list of ISO 8601 tokens produced by the parser andextended_infois eithernil(when no IXDTF suffix was present) or a map with keys:calendar,:zone_id,:zone_offsetand:tags.{:error, reason}when the string cannot be parsed or a critical IXDTF suffix is unrecognised.